==> haskell-binary-orphans-0.1.7.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-orphans
version: 0.1.7.0
id: binary-orphans-0.1.7.0-G6RlbXVg2i5LOmlVug6KDI
key: binary-orphans-0.1.7.0-G6RlbXVg2i5LOmlVug6KDI
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-orphans#readme
synopsis: Orphan instances for binary
description:
    `binary-orphans` defines orphan instances for types in some popular packages.
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Binary.Orphans
abi: 98c8b92d17c4333a3a8134e6a67f0e78
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/binary-orphans-0.1.7.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/binary-orphans-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/binary-orphans-0.1.7.0
hs-libraries: HSbinary-orphans-0.1.7.0-G6RlbXVg2i5LOmlVug6KDI
depends:
    aeson-1.1.2.0-8R262j8BseM7FTnCfGfbwu base-4.9.1.0 binary-0.8.3.0
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw
    hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    text-binary-0.2.1.1-CxSYVg6C63wHPILjLUV97J time-1.6.0.1
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
    vector-binary-instances-0.2.3.5-Do2uVjLEGQcAMYmorIf1G3
haddock-interfaces: /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock
haddock-html: /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-orphans-0.1.7.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-orphans
version: 0.1.7.0
id: binary-orphans-0.1.7.0-C1HPZ8c4Cn1G3XWFCOy9E
key: binary-orphans-0.1.7.0-C1HPZ8c4Cn1G3XWFCOy9E
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-orphans#readme
synopsis: Orphan instances for binary
description:
    `binary-orphans` defines orphan instances for types in some popular packages.
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Binary.Orphans
abi: 5a3f8b5581201abef72c5a941cb08eb1
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/binary-orphans-0.1.7.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/binary-orphans-0.1.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/binary-orphans-0.1.7.0
hs-libraries: HSbinary-orphans-0.1.7.0-C1HPZ8c4Cn1G3XWFCOy9E
depends:
    aeson-1.2.1.0-LtwtJj4trOg6E4DiroefXf base-4.9.1.0 binary-0.8.3.0
    case-insensitive-1.2.0.10-3Sa52nt2lVR6gZGQE5fZZw
    hashable-1.2.6.1-2nPqxcHq7mUGgurrYaLtXr
    scientific-0.3.5.1-3aJEdQvcyho88FhIoGrzGS
    tagged-0.8.5-DG0qxw3gXxx4NfDcDx4Iai
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
    text-binary-0.2.1.1-CxSYVg6C63wHPILjLUV97J time-1.6.0.1
    unordered-containers-0.2.8.0-1tqMF698WJE3INvmpuzQZc
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
    vector-binary-instances-0.2.3.5-Do2uVjLEGQcAMYmorIf1G3
haddock-interfaces: /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock
haddock-html: /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
